@@ -86,12 +86,22 @@ PyAPI_FUNC(int) PyCode_Addr2Line(PyCodeObject *arg0, int arg1);
 PyAPI_FUNC(int) PyCode_Check(void * arg0);
 #define PyCode_CheckExact PyPyCode_CheckExact
 PyAPI_FUNC(int) PyCode_CheckExact(void * arg0);
+#define PyCode_GetCellvars PyPyCode_GetCellvars
+PyAPI_FUNC(struct _object *) PyCode_GetCellvars(PyCodeObject *arg0);
+#define PyCode_GetCode PyPyCode_GetCode
+PyAPI_FUNC(struct _object *) PyCode_GetCode(PyCodeObject *arg0);
+#define PyCode_GetFreevars PyPyCode_GetFreevars
+PyAPI_FUNC(struct _object *) PyCode_GetFreevars(PyCodeObject *arg0);
 #define PyCode_GetNumFree PyPyCode_GetNumFree
 PyAPI_FUNC(Signed) PyCode_GetNumFree(PyCodeObject *arg0);
+#define PyCode_GetVarnames PyPyCode_GetVarnames
+PyAPI_FUNC(struct _object *) PyCode_GetVarnames(PyCodeObject *arg0);
 #define PyCode_New PyPyCode_New
-PyAPI_FUNC(PyCodeObject *) PyCode_New(int arg0, int arg1, int arg2, int arg3, int arg4, struct _object *arg5, struct _object *arg6, struct _object *arg7, struct _object *arg8, struct _object *arg9, struct _object *arg10, struct _object *arg11, struct _object *arg12, int arg13, struct _object *arg14);
+PyAPI_FUNC(struct _object *) PyCode_New(int arg0, int arg1, int arg2, int arg3, int arg4, struct _object *arg5, struct _object *arg6, struct _object *arg7, struct _object *arg8, struct _object *arg9, struct _object *arg10, struct _object *arg11, struct _object *arg12, struct _object *arg13, int arg14, struct _object *arg15);
 #define PyCode_NewEmpty PyPyCode_NewEmpty
 PyAPI_FUNC(PyCodeObject *) PyCode_NewEmpty(const char *arg0, const char *arg1, int arg2);
+#define PyCode_NewWithPosOnlyArgs PyPyCode_NewWithPosOnlyArgs
+PyAPI_FUNC(PyCodeObject *) PyCode_NewWithPosOnlyArgs(int arg0, int arg1, int arg2, int arg3, int arg4, int arg5, struct _object *arg6, struct _object *arg7, struct _object *arg8, struct _object *arg9, struct _object *arg10, struct _object *arg11, struct _object *arg12, struct _object *arg13, struct _object *arg14, int arg15, struct _object *arg16, struct _object *arg17);
 #define PyCodec_Decode PyPyCodec_Decode
 PyAPI_FUNC(struct _object *) PyCodec_Decode(struct _object *arg0, const char *arg1, const char *arg2);
 #define PyCodec_Decoder PyPyCodec_Decoder
@@ -118,6 +128,8 @@ PyAPI_FUNC(double) PyComplex_RealAsDouble(struct _object *arg0);
 PyAPI_FUNC(int) PyContextVar_Get(struct _object *arg0, struct _object *arg1, struct _object **arg2);
 #define PyContextVar_New PyPyContextVar_New
 PyAPI_FUNC(struct _object *) PyContextVar_New(const char *arg0, struct _object *arg1);
+#define PyContextVar_Reset PyPyContextVar_Reset
+PyAPI_FUNC(struct _object *) PyContextVar_Reset(struct _object *arg0, struct _object *arg1);
 #define PyContextVar_Set PyPyContextVar_Set
 PyAPI_FUNC(struct _object *) PyContextVar_Set(struct _object *arg0, struct _object *arg1);
 #define PyCoro_Check PyPyCoro_Check
@@ -242,6 +254,8 @@ PyAPI_FUNC(int) PyErr_ExceptionMatches(struct _object *arg0);
 PyAPI_FUNC(void) PyErr_Fetch(struct _object **arg0, struct _object **arg1, struct _object **arg2);
 #define PyErr_GetExcInfo PyPyErr_GetExcInfo
 PyAPI_FUNC(void) PyErr_GetExcInfo(struct _object **arg0, struct _object **arg1, struct _object **arg2);
+#define PyErr_GetHandledException PyPyErr_GetHandledException
+PyAPI_FUNC(struct _object *) PyErr_GetHandledException(void);
 #define PyErr_GivenExceptionMatches PyPyErr_GivenExceptionMatches
 PyAPI_FUNC(int) PyErr_GivenExceptionMatches(struct _object *arg0, struct _object *arg1);
 #define PyErr_NoMemory PyPyErr_NoMemory
@@ -266,6 +280,8 @@ PyAPI_FUNC(struct _object *) PyErr_SetFromErrnoWithFilename(struct _object *arg0
 PyAPI_FUNC(struct _object *) PyErr_SetFromErrnoWithFilenameObject(struct _object *arg0, struct _object *arg1);
 #define PyErr_SetFromErrnoWithFilenameObjects PyPyErr_SetFromErrnoWithFilenameObjects
 PyAPI_FUNC(struct _object *) PyErr_SetFromErrnoWithFilenameObjects(struct _object *arg0, struct _object *arg1, struct _object *arg2);
+#define PyErr_SetHandledException PyPyErr_SetHandledException
+PyAPI_FUNC(void) PyErr_SetHandledException(struct _object *arg0);
 #define PyErr_SetNone PyPyErr_SetNone
 PyAPI_FUNC(void) PyErr_SetNone(struct _object *arg0);
 #define PyErr_SetObject PyPyErr_SetObject
@@ -290,6 +306,8 @@ PyAPI_FUNC(struct _object *) PyEval_EvalCode(struct _object *arg0, struct _objec
 PyAPI_FUNC(struct _object *) PyEval_GetBuiltins(void);
 #define PyEval_GetFrame PyPyEval_GetFrame
 PyAPI_FUNC(PyFrameObject *) PyEval_GetFrame(void);
+#define PyEval_GetFuncName PyPyEval_GetFuncName
+PyAPI_FUNC(const char *) PyEval_GetFuncName(struct _object *arg0);
 #define PyEval_GetGlobals PyPyEval_GetGlobals
 PyAPI_FUNC(struct _object *) PyEval_GetGlobals(void);
 #define PyEval_GetLocals PyPyEval_GetLocals
@@ -342,6 +360,18 @@ PyAPI_FUNC(int) PyFloat_CheckExact(void * arg0);
 PyAPI_FUNC(struct _object *) PyFloat_FromDouble(double arg0);
 #define PyFloat_FromString PyPyFloat_FromString
 PyAPI_FUNC(struct _object *) PyFloat_FromString(struct _object *arg0);
+#define PyFrame_GetBuiltins PyPyFrame_GetBuiltins
+PyAPI_FUNC(struct _object *) PyFrame_GetBuiltins(PyFrameObject *arg0);
+#define PyFrame_GetGenerator PyPyFrame_GetGenerator
+PyAPI_FUNC(struct _object *) PyFrame_GetGenerator(PyFrameObject *arg0);
+#define PyFrame_GetGlobals PyPyFrame_GetGlobals
+PyAPI_FUNC(struct _object *) PyFrame_GetGlobals(PyFrameObject *arg0);
+#define PyFrame_GetLasti PyPyFrame_GetLasti
+PyAPI_FUNC(int) PyFrame_GetLasti(PyFrameObject *arg0);
+#define PyFrame_GetLineNumber PyPyFrame_GetLineNumber
+PyAPI_FUNC(int) PyFrame_GetLineNumber(PyFrameObject *arg0);
+#define PyFrame_GetLocals PyPyFrame_GetLocals
+PyAPI_FUNC(struct _object *) PyFrame_GetLocals(PyFrameObject *arg0);
 #define PyFrame_New PyPyFrame_New
 PyAPI_FUNC(PyFrameObject *) PyFrame_New(PyThreadState *arg0, PyCodeObject *arg1, struct _object *arg2, struct _object *arg3);
 #define PyFrozenSet_Check PyPyFrozenSet_Check
@@ -356,6 +386,12 @@ PyAPI_FUNC(int) PyFunction_Check(void * arg0);
 PyAPI_FUNC(int) PyFunction_CheckExact(void * arg0);
 #define PyFunction_GetCode PyPyFunction_GetCode
 PyAPI_FUNC(struct _object *) PyFunction_GetCode(struct _object *arg0);
+#define PyFunction_GetGlobals PyPyFunction_GetGlobals
+PyAPI_FUNC(struct _object *) PyFunction_GetGlobals(struct _object *arg0);
+#define PyFunction_GetModule PyPyFunction_GetModule
+PyAPI_FUNC(struct _object *) PyFunction_GetModule(struct _object *arg0);
+#define PyGC_Collect PyPyGC_Collect
+PyAPI_FUNC(int) PyGC_Collect(void);
 #define PyGC_Disable PyPyGC_Disable
 PyAPI_FUNC(int) PyGC_Disable(void);
 #define PyGC_Enable PyPyGC_Enable
@@ -451,17 +487,17 @@ PyAPI_FUNC(Signed) PyLong_AsLongLong(struct _object *arg0);
 #define PyLong_AsLongLongAndOverflow PyPyLong_AsLongLongAndOverflow
 PyAPI_FUNC(Signed) PyLong_AsLongLongAndOverflow(struct _object *arg0, int *arg1);
 #define PyLong_AsSize_t PyPyLong_AsSize_t
-PyAPI_FUNC(Unsigned) PyLong_AsSize_t(struct _object *arg0);
+PyAPI_FUNC(size_t) PyLong_AsSize_t(struct _object *arg0);
 #define PyLong_AsSsize_t PyPyLong_AsSsize_t
 PyAPI_FUNC(Signed) PyLong_AsSsize_t(struct _object *arg0);
 #define PyLong_AsUnsignedLong PyPyLong_AsUnsignedLong
-PyAPI_FUNC(Unsigned) PyLong_AsUnsignedLong(struct _object *arg0);
+PyAPI_FUNC(size_t) PyLong_AsUnsignedLong(struct _object *arg0);
 #define PyLong_AsUnsignedLongLong PyPyLong_AsUnsignedLongLong
-PyAPI_FUNC(Unsigned) PyLong_AsUnsignedLongLong(struct _object *arg0);
+PyAPI_FUNC(size_t) PyLong_AsUnsignedLongLong(struct _object *arg0);
 #define PyLong_AsUnsignedLongLongMask PyPyLong_AsUnsignedLongLongMask
-PyAPI_FUNC(Unsigned) PyLong_AsUnsignedLongLongMask(struct _object *arg0);
+PyAPI_FUNC(size_t) PyLong_AsUnsignedLongLongMask(struct _object *arg0);
 #define PyLong_AsUnsignedLongMask PyPyLong_AsUnsignedLongMask
-PyAPI_FUNC(Unsigned) PyLong_AsUnsignedLongMask(struct _object *arg0);
+PyAPI_FUNC(size_t) PyLong_AsUnsignedLongMask(struct _object *arg0);
 #define PyLong_AsVoidPtr PyPyLong_AsVoidPtr
 PyAPI_FUNC(void *) PyLong_AsVoidPtr(struct _object *arg0);
 #define PyLong_FromDouble PyPyLong_FromDouble
@@ -471,7 +507,7 @@ PyAPI_FUNC(struct _object *) PyLong_FromLong(Signed arg0);
 #define PyLong_FromLongLong PyPyLong_FromLongLong
 PyAPI_FUNC(struct _object *) PyLong_FromLongLong(Signed arg0);
 #define PyLong_FromSize_t PyPyLong_FromSize_t
-PyAPI_FUNC(struct _object *) PyLong_FromSize_t(Unsigned arg0);
+PyAPI_FUNC(struct _object *) PyLong_FromSize_t(size_t arg0);
 #define PyLong_FromSsize_t PyPyLong_FromSsize_t
 PyAPI_FUNC(struct _object *) PyLong_FromSsize_t(Signed arg0);
 #define PyLong_FromString PyPyLong_FromString
@@ -481,9 +517,9 @@ PyAPI_FUNC(struct _object *) PyLong_FromUnicode(wchar_t *arg0, Signed arg1, int
 #define PyLong_FromUnicodeObject PyPyLong_FromUnicodeObject
 PyAPI_FUNC(struct _object *) PyLong_FromUnicodeObject(struct _object *arg0, int arg1);
 #define PyLong_FromUnsignedLong PyPyLong_FromUnsignedLong
-PyAPI_FUNC(struct _object *) PyLong_FromUnsignedLong(Unsigned arg0);
+PyAPI_FUNC(struct _object *) PyLong_FromUnsignedLong(size_t arg0);
 #define PyLong_FromUnsignedLongLong PyPyLong_FromUnsignedLongLong
-PyAPI_FUNC(struct _object *) PyLong_FromUnsignedLongLong(Unsigned arg0);
+PyAPI_FUNC(struct _object *) PyLong_FromUnsignedLongLong(size_t arg0);
 #define PyLong_FromVoidPtr PyPyLong_FromVoidPtr
 PyAPI_FUNC(struct _object *) PyLong_FromVoidPtr(void *arg0);
 #define PyMapping_Check PyPyMapping_Check
@@ -661,13 +697,9 @@ PyAPI_FUNC(struct _object *) PyObject_CallObject(struct _object *arg0, struct _o
 #define PyObject_CallOneArg PyPyObject_CallOneArg
 PyAPI_FUNC(struct _object *) PyObject_CallOneArg(struct _object *arg0, struct _object *arg1);
 #define PyObject_Calloc PyPyObject_Calloc
-PyAPI_FUNC(void *) PyObject_Calloc(Unsigned arg0, Unsigned arg1);
+PyAPI_FUNC(void *) PyObject_Calloc(size_t arg0, size_t arg1);
 #define PyObject_ClearWeakRefs PyPyObject_ClearWeakRefs
 PyAPI_FUNC(void) PyObject_ClearWeakRefs(struct _object *arg0);
-#define PyObject_DelAttr PyPyObject_DelAttr
-PyAPI_FUNC(int) PyObject_DelAttr(struct _object *arg0, struct _object *arg1);
-#define PyObject_DelAttrString PyPyObject_DelAttrString
-PyAPI_FUNC(int) PyObject_DelAttrString(struct _object *arg0, const char *arg1);
 #define PyObject_DelItem PyPyObject_DelItem
 PyAPI_FUNC(int) PyObject_DelItem(struct _object *arg0, struct _object *arg1);
 #define PyObject_Dir PyPyObject_Dir
@@ -711,13 +743,13 @@ PyAPI_FUNC(int) PyObject_IsTrue(struct _object *arg0);
 #define PyObject_LengthHint PyPyObject_LengthHint
 PyAPI_FUNC(Py_ssize_t) PyObject_LengthHint(PyObject * arg0, Py_ssize_t arg1);
 #define PyObject_Malloc PyPyObject_Malloc
-PyAPI_FUNC(void *) PyObject_Malloc(Unsigned arg0);
+PyAPI_FUNC(void *) PyObject_Malloc(size_t arg0);
 #define PyObject_Not PyPyObject_Not
 PyAPI_FUNC(int) PyObject_Not(struct _object *arg0);
 #define PyObject_Print PyPyObject_Print
 PyAPI_FUNC(int) PyObject_Print(struct _object *arg0, FILE *arg1, int arg2);
 #define PyObject_Realloc PyPyObject_Realloc
-PyAPI_FUNC(void *) PyObject_Realloc(void *arg0, Unsigned arg1);
+PyAPI_FUNC(void *) PyObject_Realloc(void *arg0, size_t arg1);
 #define PyObject_Repr PyPyObject_Repr
 PyAPI_FUNC(struct _object *) PyObject_Repr(struct _object *arg0);
 #define PyObject_RichCompare PyPyObject_RichCompare
@@ -852,14 +884,22 @@ PyAPI_FUNC(void) PyThreadState_Clear(PyThreadState *arg0);
 PyAPI_FUNC(void) PyThreadState_Delete(PyThreadState *arg0);
 #define PyThreadState_DeleteCurrent PyPyThreadState_DeleteCurrent
 PyAPI_FUNC(void) PyThreadState_DeleteCurrent(void);
+#define PyThreadState_EnterTracing PyPyThreadState_EnterTracing
+PyAPI_FUNC(void) PyThreadState_EnterTracing(PyThreadState *arg0);
 #define PyThreadState_Get PyPyThreadState_Get
 PyAPI_FUNC(PyThreadState *) PyThreadState_Get(void);
 #define PyThreadState_GetDict PyPyThreadState_GetDict
 PyAPI_FUNC(struct _object *) PyThreadState_GetDict(void);
+#define PyThreadState_GetFrame PyPyThreadState_GetFrame
+PyAPI_FUNC(PyFrameObject *) PyThreadState_GetFrame(PyThreadState *arg0);
+#define PyThreadState_GetID PyPyThreadState_GetID
+PyAPI_FUNC(size_t) PyThreadState_GetID(PyThreadState *arg0);
+#define PyThreadState_LeaveTracing PyPyThreadState_LeaveTracing
+PyAPI_FUNC(void) PyThreadState_LeaveTracing(PyThreadState *arg0);
 #define PyThreadState_New PyPyThreadState_New
 PyAPI_FUNC(PyThreadState *) PyThreadState_New(PyInterpreterState *arg0);
 #define PyThreadState_SetAsyncExc PyPyThreadState_SetAsyncExc
-PyAPI_FUNC(int) PyThreadState_SetAsyncExc(Unsigned arg0, struct _object *arg1);
+PyAPI_FUNC(int) PyThreadState_SetAsyncExc(size_t arg0, struct _object *arg1);
 #define PyThreadState_Swap PyPyThreadState_Swap
 PyAPI_FUNC(PyThreadState *) PyThreadState_Swap(PyThreadState *arg0);
 #define PyThread_exit_thread PyPyThread_exit_thread
@@ -902,6 +942,8 @@ PyAPI_FUNC(struct _object *) PyUnicode_AsEncodedObject(struct _object *arg0, con
 PyAPI_FUNC(struct _object *) PyUnicode_AsEncodedString(struct _object *arg0, const char *arg1, const char *arg2);
 #define PyUnicode_AsLatin1String PyPyUnicode_AsLatin1String
 PyAPI_FUNC(struct _object *) PyUnicode_AsLatin1String(struct _object *arg0);
+#define PyUnicode_AsRawUnicodeEscapeString PyPyUnicode_AsRawUnicodeEscapeString
+PyAPI_FUNC(struct _object *) PyUnicode_AsRawUnicodeEscapeString(struct _object *arg0);
 #define PyUnicode_AsUCS4 PyPyUnicode_AsUCS4
 PyAPI_FUNC(Py_UCS4 *) PyUnicode_AsUCS4(PyObject * arg0, Py_UCS4 * arg1, Py_ssize_t arg2, int arg3);
 #define PyUnicode_AsUCS4Copy PyPyUnicode_AsUCS4Copy
@@ -916,8 +958,6 @@ PyAPI_FUNC(char *) PyUnicode_AsUTF8(PyObject * arg0);
 PyAPI_FUNC(char *) PyUnicode_AsUTF8AndSize(PyObject * arg0, Py_ssize_t * arg1);
 #define PyUnicode_AsUTF8String PyPyUnicode_AsUTF8String
 PyAPI_FUNC(struct _object *) PyUnicode_AsUTF8String(struct _object *arg0);
-#define PyUnicode_AsUnicode PyPyUnicode_AsUnicode
-PyAPI_FUNC(Py_UNICODE *) PyUnicode_AsUnicode(PyObject * arg0);
 #define PyUnicode_AsUnicodeAndSize PyPyUnicode_AsUnicodeAndSize
 PyAPI_FUNC(Py_UNICODE *) PyUnicode_AsUnicodeAndSize(PyObject * arg0, Py_ssize_t * arg1);
 #define PyUnicode_AsUnicodeEscapeString PyPyUnicode_AsUnicodeEscapeString
@@ -948,6 +988,8 @@ PyAPI_FUNC(struct _object *) PyUnicode_DecodeLatin1(const char *arg0, Signed arg
 PyAPI_FUNC(struct _object *) PyUnicode_DecodeLocale(const char *arg0, const char *arg1);
 #define PyUnicode_DecodeLocaleAndSize PyPyUnicode_DecodeLocaleAndSize
 PyAPI_FUNC(struct _object *) PyUnicode_DecodeLocaleAndSize(const char *arg0, Signed arg1, const char *arg2);
+#define PyUnicode_DecodeRawUnicodeEscape PyPyUnicode_DecodeRawUnicodeEscape
+PyAPI_FUNC(struct _object *) PyUnicode_DecodeRawUnicodeEscape(const char *arg0, Signed arg1, const char *arg2);
 #define PyUnicode_DecodeUTF16 PyPyUnicode_DecodeUTF16
 PyAPI_FUNC(struct _object *) PyUnicode_DecodeUTF16(const char *arg0, Signed arg1, const char *arg2, int *arg3);
 #define PyUnicode_DecodeUTF32 PyPyUnicode_DecodeUTF32
@@ -1074,38 +1116,6 @@ PyAPI_FUNC(void) Py_ReprLeave(struct _object *arg0);
 PyAPI_FUNC(void) Py_SetRecursionLimit(int arg0);
 #define Py_UNICODE_COPY PyPy_UNICODE_COPY
 PyAPI_FUNC(void) Py_UNICODE_COPY(wchar_t *arg0, wchar_t *arg1, Signed arg2);
-#define Py_UNICODE_ISALNUM PyPy_UNICODE_ISALNUM
-PyAPI_FUNC(int) Py_UNICODE_ISALNUM(unsigned int arg0);
-#define Py_UNICODE_ISALPHA PyPy_UNICODE_ISALPHA
-PyAPI_FUNC(int) Py_UNICODE_ISALPHA(unsigned int arg0);
-#define Py_UNICODE_ISDECIMAL PyPy_UNICODE_ISDECIMAL
-PyAPI_FUNC(int) Py_UNICODE_ISDECIMAL(unsigned int arg0);
-#define Py_UNICODE_ISDIGIT PyPy_UNICODE_ISDIGIT
-PyAPI_FUNC(int) Py_UNICODE_ISDIGIT(unsigned int arg0);
-#define Py_UNICODE_ISLINEBREAK PyPy_UNICODE_ISLINEBREAK
-PyAPI_FUNC(int) Py_UNICODE_ISLINEBREAK(unsigned int arg0);
-#define Py_UNICODE_ISLOWER PyPy_UNICODE_ISLOWER
-PyAPI_FUNC(int) Py_UNICODE_ISLOWER(unsigned int arg0);
-#define Py_UNICODE_ISNUMERIC PyPy_UNICODE_ISNUMERIC
-PyAPI_FUNC(int) Py_UNICODE_ISNUMERIC(unsigned int arg0);
-#define Py_UNICODE_ISSPACE PyPy_UNICODE_ISSPACE
-PyAPI_FUNC(int) Py_UNICODE_ISSPACE(unsigned int arg0);
-#define Py_UNICODE_ISTITLE PyPy_UNICODE_ISTITLE
-PyAPI_FUNC(int) Py_UNICODE_ISTITLE(unsigned int arg0);
-#define Py_UNICODE_ISUPPER PyPy_UNICODE_ISUPPER
-PyAPI_FUNC(int) Py_UNICODE_ISUPPER(unsigned int arg0);
-#define Py_UNICODE_TODECIMAL PyPy_UNICODE_TODECIMAL
-PyAPI_FUNC(int) Py_UNICODE_TODECIMAL(unsigned int arg0);
-#define Py_UNICODE_TODIGIT PyPy_UNICODE_TODIGIT
-PyAPI_FUNC(int) Py_UNICODE_TODIGIT(unsigned int arg0);
-#define Py_UNICODE_TOLOWER PyPy_UNICODE_TOLOWER
-PyAPI_FUNC(unsigned int) Py_UNICODE_TOLOWER(unsigned int arg0);
-#define Py_UNICODE_TONUMERIC PyPy_UNICODE_TONUMERIC
-PyAPI_FUNC(double) Py_UNICODE_TONUMERIC(unsigned int arg0);
-#define Py_UNICODE_TOTITLE PyPy_UNICODE_TOTITLE
-PyAPI_FUNC(unsigned int) Py_UNICODE_TOTITLE(unsigned int arg0);
-#define Py_UNICODE_TOUPPER PyPy_UNICODE_TOUPPER
-PyAPI_FUNC(unsigned int) Py_UNICODE_TOUPPER(unsigned int arg0);
 #define _PyBytes_Eq _PyPyBytes_Eq
 PyAPI_FUNC(int) _PyBytes_Eq(struct _object *arg0, struct _object *arg1);
 #define _PyBytes_Join _PyPyBytes_Join
@@ -1142,10 +1152,6 @@ PyAPI_FUNC(struct _object *) _PyEval_GetAsyncGenFinalizer(void);
 PyAPI_FUNC(struct _object *) _PyEval_GetAsyncGenFirstiter(void);
 #define _PyEval_SliceIndex _PyPyEval_SliceIndex
 PyAPI_FUNC(int) _PyEval_SliceIndex(struct _object *arg0, Signed *arg1);
-#define _PyFloat_Unpack4 _PyPyFloat_Unpack4
-PyAPI_FUNC(double) _PyFloat_Unpack4(const unsigned char *arg0, int arg1);
-#define _PyFloat_Unpack8 _PyPyFloat_Unpack8
-PyAPI_FUNC(double) _PyFloat_Unpack8(const unsigned char *arg0, int arg1);
 #define _PyImport_AcquireLock _PyPyImport_AcquireLock
 PyAPI_FUNC(void) _PyImport_AcquireLock(void);
 #define _PyImport_ReleaseLock _PyPyImport_ReleaseLock
@@ -1153,13 +1159,13 @@ PyAPI_FUNC(int) _PyImport_ReleaseLock(void);
 #define _PyList_Extend _PyPyList_Extend
 PyAPI_FUNC(struct _object *) _PyList_Extend(struct _object *arg0, struct _object *arg1);
 #define _PyLong_AsByteArrayO _PyPyLong_AsByteArrayO
-PyAPI_FUNC(int) _PyLong_AsByteArrayO(struct _object *arg0, unsigned char *arg1, Unsigned arg2, int arg3, int arg4);
+PyAPI_FUNC(int) _PyLong_AsByteArrayO(struct _object *arg0, unsigned char *arg1, size_t arg2, int arg3, int arg4);
 #define _PyLong_AsInt _PyPyLong_AsInt
 PyAPI_FUNC(int) _PyLong_AsInt(struct _object *arg0);
 #define _PyLong_FromByteArray _PyPyLong_FromByteArray
-PyAPI_FUNC(struct _object *) _PyLong_FromByteArray(const unsigned char *arg0, Unsigned arg1, int arg2, int arg3);
+PyAPI_FUNC(struct _object *) _PyLong_FromByteArray(const unsigned char *arg0, size_t arg1, int arg2, int arg3);
 #define _PyLong_NumBits _PyPyLong_NumBits
-PyAPI_FUNC(Unsigned) _PyLong_NumBits(struct _object *arg0);
+PyAPI_FUNC(size_t) _PyLong_NumBits(struct _object *arg0);
 #define _PyLong_Sign _PyPyLong_Sign
 PyAPI_FUNC(int) _PyLong_Sign(struct _object *arg0);
 #define _PyNamespace_New _PyPyNamespace_New
@@ -1178,6 +1184,8 @@ extern void * _PyPy_Malloc(Signed arg0);
 PyAPI_FUNC(int) _PySet_Next(struct _object *arg0, Signed *arg1, struct _object **arg2);
 #define _PySet_NextEntry _PyPySet_NextEntry
 PyAPI_FUNC(int) _PySet_NextEntry(struct _object *arg0, Signed *arg1, struct _object **arg2, Signed *arg3);
+#define _PyThreadState_GetDict _PyPyThreadState_GetDict
+PyAPI_FUNC(struct _object *) _PyThreadState_GetDict(PyThreadState *arg0);
 #define _PyThreadState_UncheckedGet _PyPyThreadState_UncheckedGet
 PyAPI_FUNC(PyThreadState *) _PyThreadState_UncheckedGet(void);
 #define _PyTimeZone_FromTimeZone _PyPyTimeZone_FromTimeZone
@@ -1194,8 +1202,34 @@ PyAPI_FUNC(struct _object *) _PyType_Lookup(struct _typeobject *arg0, struct _ob
 PyAPI_FUNC(int) _PyUnicode_EQ(struct _object *arg0, struct _object *arg1);
 #define _PyUnicode_EqualToASCIIString _PyPyUnicode_EqualToASCIIString
 PyAPI_FUNC(int) _PyUnicode_EqualToASCIIString(struct _object *arg0, const char *arg1);
+#define _PyUnicode_IsAlpha _PyPyUnicode_IsAlpha
+PyAPI_FUNC(int) _PyUnicode_IsAlpha(unsigned int arg0);
+#define _PyUnicode_IsDecimalDigit _PyPyUnicode_IsDecimalDigit
+PyAPI_FUNC(int) _PyUnicode_IsDecimalDigit(unsigned int arg0);
+#define _PyUnicode_IsDigit _PyPyUnicode_IsDigit
+PyAPI_FUNC(int) _PyUnicode_IsDigit(unsigned int arg0);
+#define _PyUnicode_IsLowercase _PyPyUnicode_IsLowercase
+PyAPI_FUNC(int) _PyUnicode_IsLowercase(unsigned int arg0);
+#define _PyUnicode_IsNumeric _PyPyUnicode_IsNumeric
+PyAPI_FUNC(int) _PyUnicode_IsNumeric(unsigned int arg0);
+#define _PyUnicode_IsPrintable _PyPyUnicode_IsPrintable
+PyAPI_FUNC(int) _PyUnicode_IsPrintable(unsigned int arg0);
+#define _PyUnicode_IsTitlecase _PyPyUnicode_IsTitlecase
+PyAPI_FUNC(int) _PyUnicode_IsTitlecase(unsigned int arg0);
+#define _PyUnicode_IsUppercase _PyPyUnicode_IsUppercase
+PyAPI_FUNC(int) _PyUnicode_IsUppercase(unsigned int arg0);
 #define _PyUnicode_Ready _PyPyUnicode_Ready
 PyAPI_FUNC(int) _PyUnicode_Ready(PyObject * arg0);
+#define _PyUnicode_ToDecimalDigit _PyPyUnicode_ToDecimalDigit
+PyAPI_FUNC(int) _PyUnicode_ToDecimalDigit(unsigned int arg0);
+#define _PyUnicode_ToDigit _PyPyUnicode_ToDigit
+PyAPI_FUNC(int) _PyUnicode_ToDigit(unsigned int arg0);
+#define _PyUnicode_ToLowercase _PyPyUnicode_ToLowercase
+PyAPI_FUNC(unsigned int) _PyUnicode_ToLowercase(unsigned int arg0);
+#define _PyUnicode_ToTitlecase _PyPyUnicode_ToTitlecase
+PyAPI_FUNC(unsigned int) _PyUnicode_ToTitlecase(unsigned int arg0);
+#define _PyUnicode_ToUppercase _PyPyUnicode_ToUppercase
+PyAPI_FUNC(unsigned int) _PyUnicode_ToUppercase(unsigned int arg0);
 #define _Py_HashDouble _PyPy_HashDouble
 PyAPI_FUNC(Signed) _Py_HashDouble(struct _object *arg0, double arg1);
 #define _Py_HashPointer _PyPy_HashPointer
@@ -1218,6 +1252,8 @@ PyAPI_DATA(PyObject) _Py_NotImplementedStruct;
 PyAPI_DATA(PyObject) _Py_EllipsisObject;
 #define PyDateTimeAPI PyPyDateTimeAPI
 PyAPI_DATA(PyDateTime_CAPI*) PyDateTimeAPI;
+#define Py_GenericAliasType PyPy_GenericAliasType
+PyAPI_DATA(PyTypeObject) Py_GenericAliasType;
 #define PyExc_ArithmeticError PyPyExc_ArithmeticError
 PyAPI_DATA(PyObject*) PyExc_ArithmeticError;
 #define PyExc_AssertionError PyPyExc_AssertionError
@@ -1226,6 +1262,8 @@ PyAPI_DATA(PyObject*) PyExc_AssertionError;
 PyAPI_DATA(PyObject*) PyExc_AttributeError;
 #define PyExc_BaseException PyPyExc_BaseException
 PyAPI_DATA(PyObject*) PyExc_BaseException;
+#define PyExc_BaseExceptionGroup PyPyExc_BaseExceptionGroup
+PyAPI_DATA(PyObject*) PyExc_BaseExceptionGroup;
 #define PyExc_BlockingIOError PyPyExc_BlockingIOError
 PyAPI_DATA(PyObject*) PyExc_BlockingIOError;
 #define PyExc_BrokenPipeError PyPyExc_BrokenPipeError
@@ -1252,6 +1290,8 @@ PyAPI_DATA(PyObject*) PyExc_EOFError;
 PyAPI_DATA(PyObject*) PyExc_EncodingWarning;
 #define PyExc_Exception PyPyExc_Exception
 PyAPI_DATA(PyObject*) PyExc_Exception;
+#define PyExc_ExceptionGroup PyPyExc_ExceptionGroup
+PyAPI_DATA(PyObject*) PyExc_ExceptionGroup;
 #define PyExc_FileExistsError PyPyExc_FileExistsError
 PyAPI_DATA(PyObject*) PyExc_FileExistsError;
 #define PyExc_FileNotFoundError PyPyExc_FileNotFoundError
@@ -1426,6 +1466,8 @@ PyAPI_DATA(PyTypeObject) PyMethod_Type;
 PyAPI_DATA(PyTypeObject) PyTraceBack_Type;
 #define PyCapsule_Type PyPyCapsule_Type
 PyAPI_DATA(PyTypeObject) PyCapsule_Type;
+#define PyFrame_Type PyPyFrame_Type
+PyAPI_DATA(PyTypeObject) PyFrame_Type;
 
 #undef Signed    /* xxx temporary fix */
 #undef Unsigned  /* xxx temporary fix */
