@@ -3,6 +3,7 @@ import pathlib
 import sys
 import time
 import _thread
+import threading
 import warnings
 import weakref
 import __pypy__
@@ -78,6 +79,8 @@ VERIFY_CRL_CHECK_CHAIN = lib.X509_V_FLAG_CRL_CHECK | lib.X509_V_FLAG_CRL_CHECK_A
 VERIFY_X509_STRICT = lib.X509_V_FLAG_X509_STRICT
 VERIFY_ALLOW_PROXY_CERTS = lib.X509_V_FLAG_ALLOW_PROXY_CERTS
 VERIFY_X509_TRUSTED_FIRST = lib.X509_V_FLAG_TRUSTED_FIRST
+if lib.Cryptography_HAS_X509_V_FLAG_PARTIAL_CHAIN:
+    VERIFY_X509_PARTIAL_CHAIN = lib.X509_V_FLAG_PARTIAL_CHAIN
 if lib.Cryptography_HAS_X509_CHECK_FLAG_NEVER_CHECK_SUBJECT:
     HOSTFLAG_NEVER_CHECK_SUBJECT = lib.X509_CHECK_FLAG_NEVER_CHECK_SUBJECT
 
@@ -99,7 +102,7 @@ if OPENSSL_VERSION_INFO > (1, 1, 0, 0, 0):
     # OP_ENABLE_MIDDLEBOX_COMPAT = lib.SSL_OP_ENABLE_MIDDLEBOX_COMPAT
     # XXX should be conditionally compiled into lib
     OP_ENABLE_MIDDLEBOX_COMPAT = 0x00100000
-
+    OP_NO_RENEGOTIATION = 0x40000000
 
 
 SSL_CLIENT = 0
@@ -720,11 +723,12 @@ class _SSLSocket(object):
         sock = self.get_socket_or_connection_gone()
 
         mem = ffi.from_buffer(buffer_into)
-        if length <= 0 or length > len(buffer_into):
-            length = len(buffer_into)
+        max_mem = len(mem)
+        if length <= 0 or length > max_mem:
+            length = max_mem
             if length > _MAX_INT:
                 raise OverflowError("maximum length can't fit in a C 'int'")
-            if len(buffer_into) == 0:
+            if max_mem == 0:
                 return 0
 
         if sock:
@@ -758,6 +762,7 @@ class _SSLSocket(object):
             elif err.ssl == SSL_ERROR_ZERO_RETURN and \
                  lib.SSL_get_shutdown(self.ssl) == lib.SSL_RECEIVED_SHUTDOWN:
                 count[0] = 0
+                retval = 1  # in _ssl.c this is 'goto done' to avoid raising an error
                 break;
             else:
                 sockstate = SOCKET_OPERATION_OK
@@ -835,6 +840,8 @@ class _SSLSocket(object):
     def version(self):
         if self.ssl == ffi.NULL:
             return None
+        if not lib.SSL_is_init_finished(self.ssl):
+            return None
         version = _str_from_buf(lib.SSL_get_version(self.ssl))
         if version == "unknown":
             return None
@@ -852,6 +859,8 @@ class _SSLSocket(object):
             3) self.socket() is not None
             This method returns True if there is not weakref object allocated
         """
+        if not self.ssl:
+            raise TypeError("requires a valid context")
         if self.socket is None:
             return None
         sock = self.socket()
@@ -1141,16 +1150,26 @@ for name in SSL_CTX_STATS_NAMES:
     assert hasattr(lib, attr)
     SSL_CTX_STATS.append((name, getattr(lib, attr)))
 
+HAS_KEYLOG = hasattr(lib, "SSL_CTX_set_keylog_callback")
+
+slots = ['ctx', '_check_hostname',
+         'alpn_protocols', '_alpn_protocols_handle', '_protocol'
+         'npn_protocols', 'set_hostname', '_post_handshake_auth',
+         '_sni_cb', '_sni_cb_handle', '_npn_protocols_handle',
+        ]
+if HAS_KEYLOG:
+    slots += ['_keylog_filename', 'keylog_bio']
+
 class _SSLContext(object):
-    __slots__ = ('ctx', '_check_hostname',
-                 'alpn_protocols', '_alpn_protocols_handle', '_protocol'
-                 'npn_protocols', 'set_hostname', '_post_handshake_auth',
-                 '_sni_cb', '_sni_cb_handle', '_npn_protocols_handle')
+    __slots__ = tuple(slots)
     def __new__(cls, protocol):
         self = object.__new__(cls)
         self.ctx = ffi.NULL
         self._sni_cb = None
         self._msg_cb = None
+        if HAS_KEYLOG:
+            self._keylog_filename = None
+            self.keylog_bio = None
         if protocol == PROTOCOL_TLSv1:
             warnings.warn("ssl.PROTOCOL_TLSv1 is deprecated", DeprecationWarning)
             method = lib.TLSv1_method()
@@ -1260,7 +1279,10 @@ class _SSLContext(object):
             lib.SSL_OP_NO_SSLv2 | lib.SSL_OP_NO_SSLv3 | lib.SSL_OP_NO_TLSv1 |
             lib.SSL_OP_NO_TLSv1_1 | lib.SSL_OP_NO_TLSv1_2 | lib.SSL_OP_NO_TLSv1_3
         )
-        new_opts = int(value)
+        try:
+            new_opts = int(value)
+        except ValueError:
+            raise TypeError(f"argument must be int, not '{type(value).__name__}'") from None
         opts = lib.SSL_CTX_get_options(self.ctx)
         clear = opts & ~new_opts
         set = ~opts & new_opts
@@ -1670,6 +1692,42 @@ class _SSLContext(object):
         self._msg_cb = arg
         lib.SSL_CTX_set_msg_callback(self.ctx, _msg_callback)
 
+    if HAS_KEYLOG:
+        @property
+        def keylog_filename(self):
+            return self._keylog_filename
+
+        @keylog_filename.setter
+        def keylog_filename(self, arg):
+            # In CPython, this is in _ssl/debughelpers.c
+            # Reset variables and callback first
+            lib.SSL_CTX_set_keylog_callback(self.ctx, ffi.NULL)
+            if (self.keylog_bio != None):
+                bio = self.keylog_bio
+                self.keylog_bio = None
+                lib.BIO_free_all(bio)
+            if arg is None:
+                self._keylog_filename = None
+                return 0
+            if not isinstance(arg, str):
+                raise TypeError("str path expected")
+            buf = _fs_converter(arg, "arg")
+            mode = ffi.new("char[]", b"at")
+            ffi.errno = 0
+            self.keylog_bio = lib.BIO_new_file(buf, mode)
+            if self.keylog_bio == ffi.NULL:
+                _errno = ffi.errno
+                lib.ERR_clear_error()
+                raise OSError(_errno, '')
+            self._keylog_filename = arg
+            # Write a header for seekable, empty files (this excludes pipes).
+            if lib.BIO_tell(self.keylog_bio) == 0:
+                lib.BIO_puts(self.keylog_bio,
+                         "# TLS secrets log file, generated by OpenSSL / Python\n".encode())
+                lib.BIO_flush(self.keylog_bio)
+            lib.SSL_CTX_set_keylog_callback(self.ctx, _keylog_callback)
+            return 0
+
     def cert_store_stats(self):
         store = lib.SSL_CTX_get_cert_store(self.ctx)
         x509 = 0
@@ -1840,6 +1898,11 @@ class _SSLContext(object):
 
         return 0;
 
+    def __del__(self):
+        # In CPython this is done via context_clear
+        if HAS_KEYLOG and self.keylog_bio:
+            lib.BIO_free_all(self.keylog_bio)
+            self.keylog_bio = None
 
 
 # cryptography constraint: OPENSSL_NO_TLSEXT will never be set!
@@ -1964,6 +2027,30 @@ def _msg_callback(write_p, version, content_type, buf, length, ssl, arg):
                               version, content_type, msg_type,
                               bytes(ffi.buffer(cbuf, length)))
 
+keylog_callback_lock = threading.Lock()
+
+@ffi.callback("void(SSL*, const char *)")
+def _keylog_callback(ssl, line):
+    ssl_obj = ffi.from_handle(lib.SSL_get_app_data(ssl))
+    bio = ssl_obj.ctx.keylog_bio
+    if not bio:
+        return
+    keylog_callback_lock.acquire(True)
+    if isinstance(line, str):
+        line = line.encode()
+        buff = ffi.from_buffer(line)
+    elif isinstance(line, bytes):
+        buff = ffi.from_buffer(line)
+    else:
+        buff = line
+    fmt = ffi.from_buffer(b"%s\n")
+    res = lib.BIO_printf(bio, fmt, buff)
+    e = ffi.errno
+    lib.BIO_flush(bio)
+    keylog_callback_lock.release()
+    if res < 0:
+        raise OSError(e, ssl_obj.ctx.keylog_filename)
+
 class GenericCallback(object):
     def __init__(self, callback, ctx):
         self.callback = callback
@@ -2028,9 +2115,8 @@ class MemoryBIO(object):
     def write(self, strlike):
         INT_MAX = 2**31-1
         if isinstance(strlike, memoryview):
-            # FIXME pypy must support get_raw_address for
-            # StringBuffer to remove this case!
-            strlike = strlike.tobytes()
+            if not strlike.c_contiguous:
+                raise BufferError("memoryview: underlying buffer is not C-contiguous")
         buf = ffi.from_buffer(strlike)
         if len(buf) > INT_MAX:
             raise OverflowError("string longer than %d bytes", INT_MAX)
